#!/bin/bash
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# chmod 755 ./chained-plugin-test-setup.sh

WARN="[\e[1;33mWARN\e[0m]"
ERROR="[\e[1;31mERROR\e[0m]"
INFO="[\e[1;34mINFO\e[0m]"

function LOG () {
  echo -e "$1 $2"
}

POLICY_ITEM_COUNT=1000	#Default value

LOG $INFO "Evaluating script parameter provided"
## policy item count is provided
if [ -z "$1" ]
  then
    LOG $WARN "Max script iteration by each client not supplied using default ($POLICY_ITEM_COUNT)"
  else
    POLICY_ITEM_COUNT=$1
fi

# Create run & input directory
TEST_DATA_DIR="chained-plugin-input-$(date +%s)"

mkdir -p "$TEST_DATA_DIR"

# Copy input files
cp input/cm_hdfs.json "$TEST_DATA_DIR"
cp input/ranger-config.xml "$TEST_DATA_DIR"
cp input/test_modules.txt "$TEST_DATA_DIR"

# Update test data directory
sed -i "s/DATA_DIR/$TEST_DATA_DIR/g" "$TEST_DATA_DIR/ranger-config.xml"

# Generate input files
python chained-plugin-input-generator.py --inputPath input/ --outputPath "$TEST_DATA_DIR" --policyItems $POLICY_ITEM_COUNT

# Run python script
LOG $INFO "Command: 'bash ./ranger-perftester.sh -s $TEST_DATA_DIR/cm_hdfs.json -r $TEST_DATA_DIR/test_requests_hdfs.json -c 2 -n 1 -t -d -f $TEST_DATA_DIR/ranger-config.xml -p $TEST_DATA_DIR/test_modules.txt'"

